# import the required library 
import numpy as np 
import cv2 
from matplotlib import pyplot as plt 
  
  
# read the image 
img = cv2.imread('files/img/stacked_bond.png') 
  
# convert image to gray scale image 
gray = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY) 
  
# detect corners with the goodFeaturesToTrack function. 
corners = cv2.goodFeaturesToTrack(gray, 27, 0.01, 10) 
corners = np.int0(corners) 
  
# we iterate through each corner,  
# making a circle at each point that we think is a corner. 
for i in corners: 
    x, y = i.ravel() 
    cv2.circle(img, (x, y), 3, 255, -1) 
  
plt.imshow(img)
plt.show() 



# Python programe to illustrate  
# arithmetic operation of 
# addition of two images 
    
# organizing imports  
import cv2  
import numpy as np  
import os

# path to input images are specified and   
# images are loaded with imread command  
image1 = cv2.imread('input1.jpg')  
image2 = cv2.imread('input2.jpg') 
directory = "img" 
# cv2.addWeighted is applied over the 
# image inputs with applied parameters 
weightedSum = cv2.addWeighted(image1, 0.5, image2, 0.4, 0) 

#os.chdir(directory) 
  
# List files and directories   
# in 'C:/Users/Rajnish/Desktop/GeeksforGeeks'   
print("Before saving image:")   
print(os.listdir(directory))   
  
# Filename 
filename = 'img/input1input2.jpg'
  
# Using cv2.imwrite() method 
# Saving the image 
cv2.imwrite(filename, weightedSum) 
  
# List files and directories   
# in 'C:/Users / Rajnish / Desktop / GeeksforGeeks'   
print("After saving image:")    
print(os.listdir(directory))   
print('Successfully saved') 



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (C) 2020  David Arroyo Menéndez

# Author: David Arroyo Menéndez <davidam@gnu.org>
# Maintainer: David Arroyo Menéndez <davidam@gnu.org>

# This file is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.

# This file is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with DameOpenCV; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA 02110-1301 USA,

from setuptools import setup
from os import path

setup(name='dameopencv',
      version='0.0.5',
      description='Learning OpenCV from Tests by David Arroyo Menéndez',
      classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Programming Language :: Python :: 3.6',
        'Topic :: Scientific/Engineering',
      ],
      keywords='opencv tests',
      url='http://github.com/davidam/dameopencv',
      author='David Arroyo Menéndez',
      author_email='davidam@gnu.org',
      license='GPLv3',
      packages=['dameopencv', 'dameopencv.tests'],
      package_dir={'dameopencv': 'dameopencv', 'dameopencv.tests': 'dameopencv/tests'},
      install_requires=[
          'markdown',
          'numpy',
      ],
      test_suite='nose.collector',
      tests_require=['nose', 'nose-cover3'],
      entry_points={
          'console_scripts': ['dameopencv=dameopencv'],
      },
      include_package_data=True,
      zip_safe=False)



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (C) 2019  David Arroyo Menéndez

# Author: David Arroyo Menéndez <davidam@gnu.org>
# Maintainer: David Arroyo Menéndez <davidam@gnu.org>

# This file is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.

# This file is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with Damenumpy; see the file LICENSE.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA 02110-1301 USA,

from unittest import TestCase
import cv2 
import os 

import numpy as np

class TestBasics(TestCase):

    def test_write(self):
        # Image path 
        image_path = 'files/img/woman1.jpg'
  
        # Image directory 
        directory = 'files/img'
  
        # Using cv2.imread() method 
        # to read the image 
        img = cv2.imread(image_path)   
  
        # Filename 
        filename = 'files/img/savedImage.jpg'
  
        # Using cv2.imwrite() method 
        # Saving the image 
        cv2.imwrite(filename, img) 
        
        self.assertEqual(len(os.listdir(directory)), 14)
        
        try:
            os.remove(filename)
            self.assertEqual(len(os.listdir(directory)), 13)
        except OSError as e:  ## if failed, report it back to the user ##
            print ("Error: %s - %s." % (e.filename, e.strerror))

